@@ -7,7 +7,6 @@ import random
 import gzip
 
 from Bio import SeqIO
-
 from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
 from bcbio import utils
@@ -158,7 +157,7 @@ def is_fastq(in_file):
     second_ext = os.path.splitext(base)[1]
     if first_ext in fastq_ends:
         return True
-    elif second_ext + first_ext in product(fastq_ends, zip_ends):
+    elif (second_ext, first_ext) in product(fastq_ends, zip_ends):
         return True
     else:
         return False
@@ -236,6 +235,8 @@ def estimate_read_length(fastq_file, quality_format="fastq-sanger", nreads=1000)
 def open_fastq(in_file):
     """ open a fastq file, using gzip if it is gzipped
     """
+    if in_file.startswith("s3:"):
+        return utils.s3_handle(in_file)
     _, ext = os.path.splitext(in_file)
     if ext == ".gz":
         return gzip.open(in_file, 'rb')
