@@ -5,7 +5,7 @@ from bcbio.bam import callable
 from bcbio.rnaseq import sailfish
 from bcbio.ngsalign import alignprep
 from bcbio.pipeline import (archive, disambiguate, qcsummary, sample,
-                            shared, variation, rnaseq)
+                            main, shared, variation, run_info, rnaseq)
 from bcbio.variation import (bamprep, bedutils, coverage, genotype, ensemble,
                              joint, multi, population, recalibrate, validate,
                              vcfutils)
@@ -30,6 +30,10 @@ def process_alignment(*args):
 def postprocess_alignment(*args):
     return sample.postprocess_alignment(*args)
 
+@utils.map_wrap
+def prep_samples(*args):
+    return sample.prep_samples(*args)
+
 @utils.map_wrap
 def prep_align_inputs(*args):
     return alignprep.create_inputs(*args)
@@ -149,3 +153,14 @@ def cufflinks_assemble(*args):
 @utils.map_wrap
 def cufflinks_merge(*args):
     return rnaseq.cufflinks_merge(*args)
+
+@utils.map_wrap
+def organize_samples(*args):
+    return run_info.organize_samples(*args)
+
+@utils.map_wrap
+def run_main(*args):
+    work_dir, ready_config_file, systemconfig, fcdir, parallel, samples = args
+    return main.run_main(work_dir, run_info_yaml=ready_config_file,
+                         config_file=systemconfig, fc_dir=fcdir,
+                         parallel=parallel, samples=samples)
