@@ -7,10 +7,6 @@ import shutil
 import subprocess
 
 import toolz as tz
-try:
-    import pybedtools
-except ImportError:
-    pybedtools = None
 
 from bcbio import bam, utils
 from bcbio.bam import cram
@@ -134,10 +130,8 @@ def _find_read_splits(in_file, split_size):
     last = 1
     for chunki in range(num_lines // split_lines + min(1, num_lines % split_lines)):
         new = last + split_lines - 1
-        chunks.append((last, min(new, num_lines - 1)))
-        last = new
-        if chunki > 0:
-            last += 1
+        chunks.append((last, min(new, num_lines)))
+        last = new + 1
     return chunks
 
 # ## bgzip and grabix
@@ -167,11 +161,12 @@ def _bgzip_from_cram(cram_file, dirs, data):
     Returns a list with a single file, for single end CRAM files, or two
     files for paired end input.
     """
+    import pybedtools
     region_file = (tz.get_in(["config", "algorithm", "variant_regions"], data)
                    if tz.get_in(["config", "algorithm", "coverage_interval"], data) in ["regional", "exome"]
                    else None)
     if region_file:
-        regions = ["%s:%s-%s" % tuple(r) for r in pybedtools.BedTool(region_file)]
+        regions = ["%s:%s-%s" % tuple(r[:3]) for r in pybedtools.BedTool(region_file)]
     else:
         regions = [None]
     work_dir = utils.safe_makedir(os.path.join(dirs["work"], "align_prep"))
@@ -348,7 +343,7 @@ def _bgzip_from_fastq(data):
     config = data["config"]
     grabix = config_utils.get_program("grabix", config)
     needs_convert = config["algorithm"].get("quality_format", "").lower() == "illumina"
-    if in_file.endswith(".gz"):
+    if in_file.endswith(".gz") and not in_file.startswith(utils.SUPPORTED_REMOTES):
         needs_bgzip, needs_gunzip = _check_gzipped_input(in_file, grabix, needs_convert)
     else:
         needs_bgzip, needs_gunzip = True, False
