@@ -12,11 +12,11 @@ import string
 import toolz as tz
 import yaml
 
-from bcbio import utils
+from bcbio import install, utils
 from bcbio.log import logger
 from bcbio.illumina import flowcell
 from bcbio.pipeline import alignment, config_utils, genome
-from bcbio.variation import effects, genotype, population
+from bcbio.variation import effects, genotype, population, joint
 from bcbio.variation.cortex import get_sample_name
 from bcbio.bam.fastq import open_fastq
 
@@ -34,9 +34,6 @@ def organize(dirs, config, run_info_yaml):
     run_details = _run_info_from_yaml(dirs["flowcell"], run_info_yaml, config)
     out = []
     for item in run_details:
-        # add algorithm details to configuration, avoid double specification
-        item["config"] = config_utils.update_w_custom(config, item)
-        item.pop("algorithm", None)
         item["dirs"] = dirs
         if "name" not in item:
             item["name"] = ["", item["description"]]
@@ -44,6 +41,10 @@ def organize(dirs, config, run_info_yaml):
             description = "%s-%s" % (item["name"], clean_name(item["description"]))
             item["name"] = [item["name"], description]
             item["description"] = description
+        # add algorithm details to configuration, avoid double specification
+        item["resources"] = _add_remote_resources(item["resources"])
+        item["config"] = config_utils.update_w_custom(config, item)
+        item.pop("algorithm", None)
         item = add_reference_resources(item)
         # Create temporary directories and make absolute
         if utils.get_in(item, ("config", "resources", "tmp", "dir")):
@@ -53,13 +54,63 @@ def organize(dirs, config, run_info_yaml):
         out.append(item)
     return out
 
+def organize_samples(run_info_yaml, bcbio_system, work_dir, fc_dir, config):
+    """Externally callable function to read and organize configurations for samples.
+    """
+    config, config_file = config_utils.load_system_config(bcbio_system, work_dir)
+    if config.get("log_dir", None) is None:
+        config["log_dir"] = os.path.join(work_dir, "log")
+    dirs = setup_directories(work_dir, fc_dir, config, config_file)
+    return organize(dirs, config, run_info_yaml)
+
+def setup_directories(work_dir, fc_dir, config, config_file):
+    fastq_dir, galaxy_dir, config_dir = _get_full_paths(flowcell.get_fastq_dir(fc_dir)
+                                                        if fc_dir else None,
+                                                        config, config_file)
+    return {"fastq": fastq_dir, "galaxy": galaxy_dir,
+            "work": work_dir, "flowcell": fc_dir, "config": config_dir}
+
+def _get_full_paths(fastq_dir, config, config_file):
+    """Retrieve full paths for directories in the case of relative locations.
+    """
+    if fastq_dir:
+        fastq_dir = utils.add_full_path(fastq_dir)
+    config_dir = utils.add_full_path(os.path.dirname(config_file))
+    galaxy_config_file = utils.add_full_path(config.get("galaxy_config", "universe_wsgi.ini"),
+                                             config_dir)
+    return fastq_dir, os.path.dirname(galaxy_config_file), config_dir
+
+# ## Remote resources
+
+def _add_remote_resources(resources):
+    """Retrieve remote resources like GATK/MuTect jars present in S3.
+    """
+    out = copy.deepcopy(resources)
+    for prog, info in resources.iteritems():
+        for key, val in info.iteritems():
+            if key == "jar" and val.startswith(utils.SUPPORTED_REMOTES):
+                store_dir = utils.safe_makedir(os.path.join(os.getcwd(), "inputs", "jars", prog))
+                fname = utils.dl_remotes(val, store_dir, store_dir)
+                version_file = os.path.join(store_dir, "version.txt")
+                if not utils.file_exists(version_file):
+                    version = install.get_gatk_jar_version(prog, fname)
+                    with open(version_file, "w") as out_handle:
+                        out_handle.write(version)
+                else:
+                    with open(version_file) as in_handle:
+                        version = in_handle.read().strip()
+                del out[prog][key]
+                out[prog]["dir"] = store_dir
+                out[prog]["version"] = version
+    return out
+
 # ## Genome reference information
 
 def add_reference_resources(data):
     """Add genome reference information to the item to process.
     """
     aligner = data["config"]["algorithm"].get("aligner", None)
-    data["reference"] = genome.get_refs(data["genome_build"], aligner, data["dirs"]["galaxy"])
+    data["reference"] = genome.get_refs(data["genome_build"], aligner, data["dirs"]["galaxy"], data)
     # back compatible `sam_ref` target
     data["sam_ref"] = utils.get_in(data, ("reference", "fasta", "base"))
     ref_loc = utils.get_in(data, ("config", "resources", "species", "dir"),
@@ -69,7 +120,7 @@ def add_reference_resources(data):
     alt_genome = utils.get_in(data, ("config", "algorithm", "validate_genome_build"))
     if alt_genome:
         data["reference"]["alt"] = {alt_genome:
-                                    genome.get_refs(alt_genome, None, data["dirs"]["galaxy"])["fasta"]}
+                                    genome.get_refs(alt_genome, None, data["dirs"]["galaxy"], data)["fasta"]}
     # Re-enable when we have ability to re-define gemini configuration directory
     if False:
         if population.do_db_build([data], check_gemini=False, need_bam=False):
@@ -89,6 +140,18 @@ def _clean_metadata(data):
         data["metadata"]["batch"] = batches
     return data
 
+def _clean_algorithm(data):
+    """Clean algorithm keys, handling items that can be specified as lists or single items.
+    """
+    # convert single items to lists
+    for key in ["variantcaller", "jointcaller"]:
+        val = tz.get_in(["algorithm", key], data)
+        if val:
+            if not isinstance(val, (list, tuple)) and isinstance(val, basestring):
+                val = [val]
+            data["algorithm"][key] = val
+    return data
+
 def _clean_characters(x):
     """Clean problem characters in sample lane or descriptions.
     """
@@ -166,7 +229,7 @@ def _check_for_misplaced(xs, subkey, other_keys):
 
 ALGORITHM_KEYS = set(["platform", "aligner", "bam_clean", "bam_sort",
                       "trim_reads", "adapters", "custom_trim", "kraken",
-                      "align_split_size", "quality_bin",
+                      "align_split_size", "quality_bin", "rsem",
                       "quality_format", "write_summary",
                       "merge_bamprep", "coverage",
                       "coverage_interval", "ploidy", "indelcaller",
@@ -288,6 +351,18 @@ def _check_variantcaller(item):
         raise ValueError("Unexpected algorithm 'variantcaller' parameter: %s\n"
                          "Supported options: %s\n" % (problem, sorted(list(allowed))))
 
+def _check_jointcaller(data):
+    """Ensure specified jointcaller is valid.
+    """
+    allowed = set(joint.get_callers() + [None, False])
+    cs = data["algorithm"].get("jointcaller", [])
+    if not isinstance(cs, (tuple, list)):
+        cs = [cs]
+    problem = [x for x in cs if x not in allowed]
+    if len(problem) > 0:
+        raise ValueError("Unexpected algorithm 'jointcaller' parameter: %s\n"
+                         "Supported options: %s\n" % (problem, sorted(list(allowed))))
+
 def _check_sample_config(items, in_file):
     """Identify common problems in input sample configuration files.
     """
@@ -304,7 +379,7 @@ def _check_sample_config(items, in_file):
     [_check_algorithm_keys(x) for x in items]
     [_check_aligner(x) for x in items]
     [_check_variantcaller(x) for x in items]
-
+    [_check_jointcaller(x) for x in items]
 
 # ## Read bcbio_sample.yaml files
 
@@ -372,6 +447,7 @@ def _run_info_from_yaml(fc_dir, run_info_yaml, config):
             pass
     global_config = {}
     global_vars = {}
+    resources = {}
     if isinstance(loaded, dict):
         global_config = copy.deepcopy(loaded)
         del global_config["details"]
@@ -379,6 +455,7 @@ def _run_info_from_yaml(fc_dir, run_info_yaml, config):
             fc_name = loaded["fc_name"].replace(" ", "_")
             fc_date = str(loaded["fc_date"]).replace(" ", "_")
         global_vars = global_config.pop("globals", {})
+        resources = global_config.pop("resources", {})
         loaded = loaded["details"]
 
     run_details = []
@@ -411,6 +488,15 @@ def _run_info_from_yaml(fc_dir, run_info_yaml, config):
         item["rgnames"] = prep_rg_names(item, config, fc_name, fc_date)
         item["test_run"] = global_config.get("test_run", False)
         item = _clean_metadata(item)
+        item = _clean_algorithm(item)
+        # Add any global resource specifications
+        if "resources" not in item:
+            item["resources"] = {}
+        for prog, pkvs in resources.iteritems():
+            if prog not in item["resources"]:
+                item["resources"][prog] = {}
+            for key, val in pkvs.iteritems():
+                item["resources"][prog][key] = val
         run_details.append(item)
     _check_sample_config(run_details, run_info_yaml)
     return run_details
