@@ -10,6 +10,7 @@ from bcbio import broad, utils
 from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
 from bcbio.pipeline import config_utils
+from bcbio.pipeline import datadict as dd
 from bcbio.provenance import do
 from bcbio.variation import vcfutils, vfilter
 
@@ -122,9 +123,11 @@ def _run_vqsr(in_file, ref_file, vrn_files, sensitivity_cutoff, filter_type, dat
             params += _get_vqsr_training(filter_type, vrn_files)
             for a in _get_vqsr_annotations(filter_type):
                 params += ["-an", a]
+            cores = dd.get_cores(data)
+            memscale = {"magnitude": 0.9 * cores, "direction": "increase"} if cores > 1 else None
             try:
                 broad_runner.new_resources("gatk-vqsr")
-                broad_runner.run_gatk(params, log_error=False)
+                broad_runner.run_gatk(params, log_error=False, memscale=memscale)
             except:  # Can fail to run if not enough values are present to train.
                 return None, None
     return recal_file, tranches_file
@@ -140,10 +143,14 @@ def _already_hard_filtered(in_file, filter_type):
 def _variant_filtration(in_file, ref_file, vrn_files, data, filter_type,
                         hard_filter_fn):
     """Filter SNP and indel variant calls using GATK best practice recommendations.
+
+    Hard filter if configuration indicates too little data or already finished a
+    hard filtering, otherwise try VQSR.
     """
-    # hard filter if configuration indicates too little data or already finished a hard filtering
     human = tz.get_in(["genome_resources", "aliases", "human"], data)
-    if (not config_utils.use_vqsr([data["config"]["algorithm"]]) or
+    # Algorithms multiplied by number of input files to check for large enough sample sizes
+    algs = [data["config"]["algorithm"]] * len(data.get("vrn_files", [1]))
+    if (not config_utils.use_vqsr(algs) or
           _already_hard_filtered(in_file, filter_type) or not human):
         return hard_filter_fn(in_file, data)
     else:
