@@ -25,7 +25,7 @@ from bcbio.variation import bamprep
 
 PairedData = namedtuple("PairedData", ["tumor_bam", "tumor_name",
                                        "normal_bam", "normal_name", "normal_panel",
-                                       "tumor_config"])
+                                       "tumor_config", "tumor_data"])
 
 def is_paired_analysis(align_bams, items):
     """Determine if BAMs are from a tumor/normal paired analysis.
@@ -46,11 +46,13 @@ def get_paired_bams(align_bams, items):
         elif phenotype == "tumor":
             tumor_bam = bamfile
             tumor_name = item["name"][1]
+            tumor_data = item
             tumor_config = item["config"]
             normal_panel = item["config"]["algorithm"].get("background")
     if tumor_bam:
         return PairedData(tumor_bam, tumor_name, normal_bam,
-                          normal_name, normal_panel, tumor_config)
+                          normal_name, normal_panel, tumor_config,
+                          tumor_data)
 
 def check_paired_problems(items):
     """Check for incorrectly paired tumor/normal samples
@@ -313,6 +315,10 @@ def combine_variant_files(orig_files, out_file, ref_file, config,
 
     Handles cases where we split files into SNPs/Indels for processing then
     need to merge back into a final file.
+
+    Will parallelize up to 4 cores based on documented recommendations:
+    https://www.broadinstitute.org/gatk/gatkdocs/
+    org_broadinstitute_gatk_tools_walkers_variantutils_CombineVariants.php
     """
     in_pipeline = False
     if isinstance(orig_files, dict):
@@ -339,7 +345,11 @@ def combine_variant_files(orig_files, out_file, ref_file, config,
             if cur_region:
                 params += ["-L", bamprep.region_to_gatk(cur_region),
                            "--interval_set_rule", "INTERSECTION"]
-            jvm_opts = broad.get_gatk_framework_opts(config)
+            cores = tz.get_in(["algorithm", "num_cores"], config, 1)
+            if cores > 1:
+                params += ["-nt", min(cores, 4)]
+            memscale = {"magnitude": 0.9 * cores, "direction": "increase"} if cores > 1 else None
+            jvm_opts = broad.get_gatk_framework_opts(config, memscale=memscale)
             cmd = [config_utils.get_program("gatk-framework", config)] + jvm_opts + params
             do.run(cmd, "Combine variant files")
     if out_file.endswith(".gz"):
